CircularPercentIndicator class

Inheritance

Constructors

CircularPercentIndicator({Key? key, double percent = 0.0, double lineWidth = 5.0, double startAngle = 0.0, required double radius, Color fillColor = Colors.transparent, Color backgroundColor = const Color(0xFFB8C7CB), Color? progressColor, double backgroundWidth = -1, LinearGradient? linearGradient, bool animation = false, int animationDuration = 500, Widget? header, Widget? footer, Widget? center, bool addAutomaticKeepAlive = true, CircularStrokeCap circularStrokeCap = CircularStrokeCap.butt, Color? arcBackgroundColor, ArcType? arcType, bool animateFromLastPercent = false, bool animateToInitialPercent = true, bool reverse = false, Curve curve = Curves.linear, MaskFilter? maskFilter, bool restartAnimation = false, VoidCallback? onAnimationEnd, Widget? widgetIndicator, bool rotateLinearGradient = false, bool clipRotatedLinearGradient = false, Color? progressBorderColor, dynamic onPercentValue(double value)?})

Properties

addAutomaticKeepAlive → bool
set false if you don't want to preserve the state of the widget
final
animateFromLastPercent → bool
set true if you want to animate the linear from the last percent value you set
final
animateToInitialPercent → bool
set to false if you do not want the default behavior of initially animating up from 0%
final
animation → bool
true if you want the circle to have animation
final
animationDuration → int
duration of the animation in milliseconds, It only applies if animation attribute is true
final
arcBackgroundColor → Color?
set a circular background color when use the arcType property
final
arcType → ArcType?
set the arc type
final
backgroundColor → Color
Color of the background of the circle , default = transparent
final
backgroundWidth → double
Width of the unfilled background of the progress bar
final
center → Widget?
widget inside the circle
final
circularStrokeCap → CircularStrokeCap
The kind of finish to place on the end of lines drawn, values supported: butt, round, square
final
clipRotatedLinearGradient → bool
Set true if you want to display only part of linearGradient based on percent value. Works only if rotateLinearGradient is true.
final
curve → Curve
set a circular curve animation type
final
fillColor → Color
First color applied to the complete circle
final
widget at the bottom of the circle
final
hashCode → int
The hash code for this object.
no setterinherited
widget at the top of the circle
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linearGradient → LinearGradient?
final
lineWidth → double
Width of the progress bar of the circle
final
maskFilter → MaskFilter?
Creates a mask filter that takes the progress shape being drawn and blurs it.
final
onAnimationEnd → VoidCallback?
Callback called when the animation ends (only if animation is true)
final
onPercentValue → dynamic Function(double value)?
Return current percent value if animation is true.
final
percent → double
Percent value between 0.0 and 1.0
final
progressBorderColor → Color?
Color of the border of the progress bar , default = null
final
progressColor → Color
no setter
radius → double
final
restartAnimation → bool
set true when you want to restart the animation, it restarts only when reaches 1.0 as a value defaults to false
final
reverse → bool
set true when you want to display the progress in reverse mode
final
rotateLinearGradient → bool
Set to true if you want to rotate linear gradient in accordance to the startAngle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAngle → double
the angle which the circle will start the progress (in degrees, eg: 0.0, 45.0, 90.0)
final
widgetIndicator → Widget?
Display a widget indicator at the end of the progress. It only works when animation is true
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CircularPercentIndicatorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited